@@ -66,10 +66,10 @@ void ExtractHereDndPlugin::setup(const KFileItemListProperties& popupMenuInfo,
 {
 
     kDebug() << "plugin setup";
-    QString extractHereMessage = i18n("Extract here");
+    const QString extractHereMessage = i18n("Extract here");
 
     if (!Kerfuffle::supportedMimeTypes().contains(popupMenuInfo.mimeType())) {
-        kDebug(1601) << "Unsupported file" << popupMenuInfo.mimeType() << Kerfuffle::supportedMimeTypes();
+        kDebug() << "Unsupported file" << popupMenuInfo.mimeType() << Kerfuffle::supportedMimeTypes();
         return;
     }
 
