@@ -46,13 +46,10 @@ ArchiveBase::ArchiveBase(ReadOnlyArchiveInterface *archive)
 {
     Q_ASSERT(archive);
     archive->setParent(this);
-    //setReadOnly( archive->isReadOnly() );
 }
 
 ArchiveBase::~ArchiveBase()
 {
-    delete m_iface;
-    m_iface = 0;
 }
 
 bool ArchiveBase::isReadOnly() const
@@ -138,7 +135,7 @@ void ArchiveBase::onListFinished(KJob* job)
     m_isSingleFolderArchive = ljob->isSingleFolderArchive();
     m_isPasswordProtected = ljob->isPasswordProtected();
     m_subfolderName = ljob->subfolderName();
-    if (m_subfolderName.isEmpty() || !m_isSingleFolderArchive) {
+    if (m_subfolderName.isEmpty()) {
         QFileInfo fi(fileName());
         QString base = fi.completeBaseName();
 
