@@ -24,6 +24,8 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include <config.h>
+
 #include "libarchivehandler.h"
 #include "kerfuffle/kerfuffle_export.h"
 #include "kerfuffle/queries.h"
@@ -341,12 +343,16 @@ bool LibArchiveInterface::addFiles(const QStringList & files, const CompressionO
         } else if (filename().right(3).toUpper() == "BZ2") {
             kDebug() << "Detected bzip2 compression for new file";
             ret = archive_write_set_compression_bzip2(arch_writer);
+#ifdef HAVE_LIBARCHIVE_XZ_SUPPORT
         } else if (filename().right(2).toUpper() == "XZ") {
             kDebug() << "Detected xz compression for new file";
             ret = archive_write_set_compression_xz(arch_writer);
+#endif
+#ifdef HAVE_LIBARCHIVE_LZMA_SUPPORT	    
         } else if (filename().right(4).toUpper() == "LZMA") {
             kDebug() << "Detected lzma compression for new file";
             ret = archive_write_set_compression_lzma(arch_writer);
+#endif	    
         } else if (filename().right(3).toUpper() == "TAR") {
             kDebug() << "Detected no compression for new file (pure tar)";
             ret = archive_write_set_compression_none(arch_writer);
@@ -372,12 +378,16 @@ bool LibArchiveInterface::addFiles(const QStringList & files, const CompressionO
         case ARCHIVE_COMPRESSION_BZIP2:
             ret = archive_write_set_compression_bzip2(arch_writer);
             break;
+#ifdef HAVE_LIBARCHIVE_XZ_SUPPORT
         case ARCHIVE_COMPRESSION_XZ:
             ret = archive_write_set_compression_xz(arch_writer);
             break;
+#endif
+#ifdef HAVE_LIBARCHIVE_LZMA_SUPPORT
         case ARCHIVE_COMPRESSION_LZMA:
             ret = archive_write_set_compression_lzma(arch_writer);
             break;
+#endif	    
         case ARCHIVE_COMPRESSION_NONE:
             ret = archive_write_set_compression_none(arch_writer);
             break;
@@ -505,12 +515,16 @@ bool LibArchiveInterface::deleteFiles(const QList<QVariant> & files)
     case ARCHIVE_COMPRESSION_BZIP2:
         ret = archive_write_set_compression_bzip2(arch_writer);
         break;
+#ifdef HAVE_LIBARCHIVE_XZ_SUPPORT
     case ARCHIVE_COMPRESSION_XZ:
         ret = archive_write_set_compression_xz(arch_writer);
         break;
+#endif
+#ifdef HAVE_LIBARCHIVE_LZMA_SUPPORT
     case ARCHIVE_COMPRESSION_LZMA:
         ret = archive_write_set_compression_lzma(arch_writer);
         break;
+#endif	
     case ARCHIVE_COMPRESSION_NONE:
         ret = archive_write_set_compression_none(arch_writer);
         break;
