@@ -1,3 +1,8 @@
+/*
+ * Copyright (C) 2006,2007 Jimmy Gilles <jimmygilles@gmail.com>
+ * Copyright (C) 2007-2009 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ */
+
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -135,10 +140,8 @@ public:
     { return !operator==(other); }
 };
 
-class KgpgKeySign : public QObject
+class KgpgKeySign
 {
-    Q_OBJECT
-
 public:
     KgpgKeySign();
     KgpgKeySign(const KgpgKeySign &other);
@@ -220,10 +223,8 @@ public:
     { return !operator==(other); }
 };
 
-class KgpgKeyUat : public QObject
+class KgpgKeyUat
 {
-    Q_OBJECT
-
 public:
     KgpgKeyUat();
     KgpgKeyUat(const KgpgKeyUat &other);
@@ -296,10 +297,8 @@ public:
     { return !operator==(other); }
 };
 
-class KgpgKeyUid : public QObject
+class KgpgKeyUid
 {
-    Q_OBJECT
-
 public:
     KgpgKeyUid();
     KgpgKeyUid(const KgpgKeyUid &other);
@@ -382,10 +381,8 @@ public:
     { return !operator==(other); }
 };
 
-class KgpgKeySub : public QObject
+class KgpgKeySub
 {
-    Q_OBJECT
-
 public:
     KgpgKeySub();
     KgpgKeySub(const KgpgKeySub &other);
@@ -486,10 +483,8 @@ public:
     { return !operator==(other); }
 };
 
-class KgpgKey : public QObject
+class KgpgKey
 {
-    Q_OBJECT
-
 public:
     static QString expiration(const QDate &date);
 
