@@ -46,9 +46,12 @@ GPGProc::resetProcess(const QString &binary)
 
 void GPGProc::start()
 {
-    connect(this, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(finished()));
-    connect(this, SIGNAL(lineReadyStandardOutput()), this, SLOT(received()));
-    KProcess::start();
+	// make sure there is exactly one connection from us to that signal
+	disconnect(this, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(finished()));
+	disconnect(this, SIGNAL(lineReadyStandardOutput()), this, SLOT(received()));
+	connect(this, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(finished()));
+	connect(this, SIGNAL(lineReadyStandardOutput()), this, SLOT(received()));
+	KProcess::start();
 }
 
 void GPGProc::received()
