@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2008,2009 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
@@ -17,14 +17,8 @@
 #include <KLocale>
 
 KGpgAddPhoto::KGpgAddPhoto(QObject *parent, const QString &keyid, const QString &imagepath)
-	: KGpgTransaction(parent)
+	: KGpgEditKeyTransaction(parent, keyid, "addphoto", false)
 {
-	addArgument("--status-fd=1");
-	addArgument("--command-fd=0");
-	addArgument("--edit-key");
-	addArgument(keyid);
-	addArgument("addphoto");
-
 	setImagePath(imagepath);
 }
 
@@ -35,29 +29,23 @@ KGpgAddPhoto::~KGpgAddPhoto()
 bool
 KGpgAddPhoto::nextLine(const QString &line)
 {
-	if (!line.startsWith("[GNUPG:] "))
+	if (!line.startsWith(QLatin1String("[GNUPG:] ")))
 		return false;
 
 	if (line.contains("GOOD_PASSPHRASE")) {
 		setSuccess(TS_MSG_SEQUENCE);
-	} else if (line.contains("passphrase.enter")) {
-		if (askPassphrase())
-			setSuccess(TS_USER_ABORTED);
-	} else if (line.contains("keyedit.prompt")) {
-		setSuccess(TS_OK);
-		write("save");
-	} else if (line.endsWith("photoid.jpeg.add")) {
+	} else if (line.endsWith(QLatin1String("photoid.jpeg.add"))) {
 		write(m_photourl.toUtf8());
+		setSuccess(TS_OK);
 	} else if (line.contains("photoid.jpeg.size")) {
 		if (KMessageBox::questionYesNo(0, i18n("This image is very large. Use it anyway?"), QString(), KGuiItem(i18n("Use Anyway")), KGuiItem(i18n("Do Not Use"))) == KMessageBox::Yes) {
-			write("Yes");
+			write("YES");
 		} else {
 			setSuccess(TS_USER_ABORTED);
 			return true;
 		}
-	} else if (line.contains("GET_")) {
-		setSuccess(TS_MSG_SEQUENCE);
-		return true;
+	} else {
+		return KGpgEditKeyTransaction::nextLine(line);
 	}
 
 	return false;
