@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2008,2009 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
@@ -13,15 +13,9 @@
 
 #include "kgpgchangetrust.h"
 
-KGpgChangeTrust::KGpgChangeTrust(QObject *parent, const QString &keyid, const KgpgCore::KgpgKeyOwnerTrust &trust)
-	: KGpgTransaction(parent)
+KGpgChangeTrust::KGpgChangeTrust(QObject *parent, const QString &keyid, const KgpgCore::KgpgKeyOwnerTrust trust)
+	: KGpgEditKeyTransaction(parent, keyid, "trust", false)
 {
-	addArgument("--status-fd=1");
-	addArgument("--command-fd=0");
-	addArgument("--edit-key");
-	addArgument(keyid);
-	addArgument("trust");
-
 	setTrust(trust);
 }
 
@@ -44,19 +38,16 @@ KGpgChangeTrust::nextLine(const QString &line)
 		write("YES");
 	} else if (line.contains("edit_ownertrust.value")) {
 		write(QByteArray::number(m_trust));
-	} else if (line.contains("keyedit.prompt")) {
 		setSuccess(TS_OK);
-		write("save");
-	} else if (line.contains("GET_")) {
-		setSuccess(TS_MSG_SEQUENCE);
-		return true;
+	} else {
+		return KGpgEditKeyTransaction::nextLine(line);
 	}
 
 	return false;
 }
 
 void
-KGpgChangeTrust::setTrust(const KgpgCore::KgpgKeyOwnerTrust &trust)
+KGpgChangeTrust::setTrust(const KgpgCore::KgpgKeyOwnerTrust trust)
 {
 	m_trust = trust;
 }
