@@ -24,6 +24,7 @@
 
 // lib
 #include "bordercolumnrenderer.h"
+#include "widgetcolumnstylist.h"
 #include "bytearraytableranges.h"
 #include "bytearraytablelayout.h"
 #include "controller/kvalueeditor.h"
@@ -48,7 +49,7 @@
 #include <QtCore/QTimer>
 
 
-namespace KHEUI
+namespace Okteta
 {
 static const int DefaultScrollTimerPeriod = 100;
 static const int InsertCursorWidth = 2;
@@ -74,24 +75,32 @@ void ByteArrayColumnViewPrivate::init()
     mDragStartTimer = new QTimer( q );
     mTrippleClickTimer = new QTimer( q );
 
+    mStylist = new WidgetColumnStylist( q );
+
     // creating the columns in the needed order
     mOffsetColumn =
-        new OffsetColumnRenderer( q, mTableLayout, KOffsetFormat::Hexadecimal );
+        new OffsetColumnRenderer( mStylist, mTableLayout, OffsetFormat::Hexadecimal );
     mFirstBorderColumn =
-        new BorderColumnRenderer( q, false );
+        new BorderColumnRenderer( mStylist, false );
     mValueColumn =
-        new ValueByteArrayColumnRenderer( q, mByteArrayModel, mTableLayout, mTableRanges );
+        new ValueByteArrayColumnRenderer( mStylist, mByteArrayModel, mTableLayout, mTableRanges );
     mSecondBorderColumn =
-        new BorderColumnRenderer( q, true );
+        new BorderColumnRenderer( mStylist, true );
     mCharColumn =
-        new CharByteArrayColumnRenderer( q, mByteArrayModel, mTableLayout, mTableRanges );
+        new CharByteArrayColumnRenderer( mStylist, mByteArrayModel, mTableLayout, mTableRanges );
+
+    q->addColumn( mOffsetColumn );
+    q->addColumn( mFirstBorderColumn );
+    q->addColumn( mValueColumn );
+    q->addColumn( mSecondBorderColumn );
+    q->addColumn( mCharColumn );
 
     // select the active column
     mActiveColumn = mCharColumn;
     mInactiveColumn = mValueColumn;
 
     // set char encoding
-    mValueColumn->setValueCodec( (KHECore::ValueCoding)mValueCoding, mValueCodec );
+    mValueColumn->setValueCodec( (ValueCoding)mValueCoding, mValueCodec );
     mValueColumn->setCharCodec( mCharCodec );
     mCharColumn->setCharCodec( mCharCodec );
 
@@ -114,13 +123,15 @@ AbstractByteArrayView::CodingTypeId ByteArrayColumnViewPrivate::activeCoding() c
     return isValueColumnActive ? AbstractByteArrayView::ValueCodingId : AbstractByteArrayView::CharCodingId;
 }
 
-int ByteArrayColumnViewPrivate::visibleCodings() const
+AbstractByteArrayView::CodingTypes ByteArrayColumnViewPrivate::visibleCodings() const
 {
-    return (mValueColumn->isVisible() ? AbstractByteArrayView::ValueCodingId : 0)
-           | (mCharColumn->isVisible() ? AbstractByteArrayView::CharCodingId : 0);
+    // TODO: try to improve this code
+    return (AbstractByteArrayView::CodingTypes)
+        ( (mValueColumn->isVisible() ? AbstractByteArrayView::ValueCodingId : 0)
+          | (mCharColumn->isVisible() ? AbstractByteArrayView::CharCodingId : 0) );
 }
 
-void ByteArrayColumnViewPrivate::setByteArrayModel( KHECore::AbstractByteArrayModel* _byteArrayModel )
+void ByteArrayColumnViewPrivate::setByteArrayModel( AbstractByteArrayModel* _byteArrayModel )
 {
     mValueEditor->reset();
 
@@ -132,7 +143,7 @@ void ByteArrayColumnViewPrivate::setByteArrayModel( KHECore::AbstractByteArrayMo
 }
 
 
-void ByteArrayColumnViewPrivate::setBufferSpacing( KPixelX ByteSpacing, int noOfGroupedBytes, KPixelX GroupSpacing )
+void ByteArrayColumnViewPrivate::setBufferSpacing( PixelX ByteSpacing, int noOfGroupedBytes, PixelX GroupSpacing )
 {
     if( !mValueColumn->setSpacing(ByteSpacing,noOfGroupedBytes,GroupSpacing) )
         return;
@@ -152,7 +163,7 @@ void ByteArrayColumnViewPrivate::setValueCoding( AbstractByteArrayView::ValueCod
 
     AbstractByteArrayViewPrivate::setValueCoding( valueCoding );
 
-    mValueColumn->setValueCodec( (KHECore::ValueCoding)mValueCoding, mValueCodec );
+    mValueColumn->setValueCodec( (ValueCoding)mValueCoding, mValueCodec );
     mValueEditor->adaptToValueCodecChange();
 
     const uint newCodingWidth = mValueCodec->encodingWidth();
@@ -167,7 +178,7 @@ void ByteArrayColumnViewPrivate::setValueCoding( AbstractByteArrayView::ValueCod
 }
 
 
-void ByteArrayColumnViewPrivate::setByteSpacingWidth( int/*KPixelX*/ byteSpacingWidth )
+void ByteArrayColumnViewPrivate::setByteSpacingWidth( int/*PixelX*/ byteSpacingWidth )
 {
     if( !mValueColumn->setByteSpacingWidth(byteSpacingWidth) )
         return;
@@ -182,7 +193,7 @@ void ByteArrayColumnViewPrivate::setNoOfGroupedBytes( int noOfGroupedBytes )
 }
 
 
-void ByteArrayColumnViewPrivate::setGroupSpacingWidth( int/*KPixelX*/ groupSpacingWidth )
+void ByteArrayColumnViewPrivate::setGroupSpacingWidth( int/*PixelX*/ groupSpacingWidth )
 {
     if( !mValueColumn->setGroupSpacingWidth(groupSpacingWidth) )
         return;
@@ -190,7 +201,7 @@ void ByteArrayColumnViewPrivate::setGroupSpacingWidth( int/*KPixelX*/ groupSpaci
 }
 
 
-void ByteArrayColumnViewPrivate::setBinaryGapWidth( int/*KPixelX*/ binaryGapWidth )
+void ByteArrayColumnViewPrivate::setBinaryGapWidth( int/*PixelX*/ binaryGapWidth )
 {
     if( !mValueColumn->setBinaryGapWidth(binaryGapWidth) )
         return;
@@ -302,18 +313,19 @@ void ByteArrayColumnViewPrivate::handleFontChange( const QFont& oldFont )
 
     // get new values
     const QFontMetrics newFontMetrics = q->fontMetrics();
-    KPixelX digitWidth = newFontMetrics.maxWidth();
-    KPixelY digitBaseLine = newFontMetrics.ascent();
-
-     q->setLineHeight( newFontMetrics.height() );
-
-    // update all dependant structures
-    mTableLayout->setNoOfLinesPerPage( q->noOfLinesPerPage() );
+    const PixelX digitWidth = newFontMetrics.maxWidth();
+    const PixelY digitBaseLine = newFontMetrics.ascent();
+    const PixelY digitHeight = newFontMetrics.height();
 
     mOffsetColumn->setMetrics( digitWidth, digitBaseLine );
     mValueColumn->setMetrics( digitWidth, digitBaseLine );
     mCharColumn->setMetrics( digitWidth, digitBaseLine );
 
+    q->setLineHeight( digitHeight );
+
+    // update all dependant structures
+    mTableLayout->setNoOfLinesPerPage( q->noOfLinesPerPage() );
+
     updateViewByWidth();
 }
 
@@ -366,25 +378,25 @@ int ByteArrayColumnViewPrivate::fittingBytesPerLine() const
     Q_Q( const ByteArrayColumnView );
 
     const QSize newSize = q->maximumViewportSize();
-    const KPixelX reservedWidth =
+    const PixelX reservedWidth =
         mOffsetColumn->visibleWidth()
         + mFirstBorderColumn->visibleWidth()
         + mSecondBorderColumn->visibleWidth();
 
     // abstract offset and border columns width
-    const KPixelX fullWidth = newSize.width() - reservedWidth;
+    const PixelX fullWidth = newSize.width() - reservedWidth;
 
     //  // no width left for resizeable columns? TODO: put this in resizeEvent
     //  if( fullWidth < 0 )
     //    return;
 
-    const KPixelY fullHeight = newSize.height();
+    const PixelY fullHeight = newSize.height();
 
     // check influence of dis-/appearing of the vertical scrollbar
     const bool verticalScrollbarIsVisible = q->verticalScrollBar()->isVisible();
-    const KPixelX scrollbarExtent = q->style()->pixelMetric( QStyle::PM_ScrollBarExtent );
+    const PixelX scrollbarExtent = q->style()->pixelMetric( QStyle::PM_ScrollBarExtent );
 
-    KPixelX availableWidth = fullWidth;
+    PixelX availableWidth = fullWidth;
     if( verticalScrollbarIsVisible )
         availableWidth -= scrollbarExtent;
 
@@ -392,11 +404,11 @@ int ByteArrayColumnViewPrivate::fittingBytesPerLine() const
     KMatchTrial matchRun = FirstRun;
 
     // prepare needed values
-    const KPixelX digitWidth = mValueColumn->digitWidth();
-    const KPixelX charByteWidth = mCharColumn->isVisible() ? digitWidth : 0;
-    const KPixelX valueByteWidth = mValueColumn->isVisible() ? mValueColumn->byteWidth() : 0;
-    const KPixelX byteSpacingWidth = mValueColumn->isVisible() ? mValueColumn->byteSpacingWidth() : 0;
-    KPixelX groupSpacingWidth;
+    const PixelX digitWidth = mValueColumn->digitWidth();
+    const PixelX charByteWidth = mCharColumn->isVisible() ? digitWidth : 0;
+    const PixelX valueByteWidth = mValueColumn->isVisible() ? mValueColumn->byteWidth() : 0;
+    const PixelX byteSpacingWidth = mValueColumn->isVisible() ? mValueColumn->byteSpacingWidth() : 0;
+    PixelX groupSpacingWidth;
     int noOfGroupedBytes = mValueColumn->noOfGroupedBytes();
     // no grouping?
     if( noOfGroupedBytes == 0 )
@@ -408,9 +420,9 @@ int ByteArrayColumnViewPrivate::fittingBytesPerLine() const
     else
         groupSpacingWidth = mValueColumn->isVisible() ? mValueColumn->groupSpacingWidth() : 0;
 
-    const KPixelX valueByteGroupWidth =  noOfGroupedBytes * valueByteWidth + (noOfGroupedBytes-1)*byteSpacingWidth;
-    const KPixelX charByteGroupWidth = noOfGroupedBytes * charByteWidth;
-    const KPixelX totalGroupWidth = valueByteGroupWidth + groupSpacingWidth + charByteGroupWidth;
+    const PixelX valueByteGroupWidth =  noOfGroupedBytes * valueByteWidth + (noOfGroupedBytes-1)*byteSpacingWidth;
+    const PixelX charByteGroupWidth = noOfGroupedBytes * charByteWidth;
+    const PixelX totalGroupWidth = valueByteGroupWidth + groupSpacingWidth + charByteGroupWidth;
 
     int fittingBytesPerLine;
     int fittingBytesPerLineWithScrollbar = 0;
@@ -431,7 +443,7 @@ int ByteArrayColumnViewPrivate::fittingBytesPerLine() const
         fittingBytesPerLine = noOfGroupedBytes * fittingGroupsPerLine;
 
         // not only full groups?
-        if( mResizeStyle == AbstractByteArrayView::FullSizeUsage && noOfGroupedBytes > 1 )
+        if( mResizeStyle == AbstractByteArrayView::FullSizeLayoutStyle && noOfGroupedBytes > 1 )
         {
 
             if( fittingGroupsPerLine > 0 )
@@ -466,7 +478,7 @@ int ByteArrayColumnViewPrivate::fittingBytesPerLine() const
 
         const int newNoOfLines = (mTableLayout->length()+mTableLayout->startOffset()+fittingBytesPerLine-1)
                                  / fittingBytesPerLine;
-        const KPixelY newHeight =  newNoOfLines * q->lineHeight();
+        const PixelY newHeight =  newNoOfLines * q->lineHeight();
 
         if( verticalScrollbarIsVisible )
         {
@@ -514,12 +526,12 @@ void ByteArrayColumnViewPrivate::setVisibleCodings( int newColumns )
     const int oldColumns = visibleCodings();
 
     // no changes or no column selected?
-    if( newColumns == oldColumns || !(newColumns&AbstractByteArrayView::BothCodingsId) )
+    if( newColumns == oldColumns || !(newColumns&AbstractByteArrayView::ValueAndCharCodings) )
         return;
 
     mValueColumn->setVisible( AbstractByteArrayView::ValueCodingId & newColumns );
     mCharColumn->setVisible( AbstractByteArrayView::CharCodingId & newColumns );
-    mSecondBorderColumn->setVisible( newColumns == AbstractByteArrayView::BothCodingsId );
+    mSecondBorderColumn->setVisible( newColumns == AbstractByteArrayView::ValueAndCharCodings );
 
     // active column not visible anymore?
     if( !mActiveColumn->isVisible() )
@@ -580,14 +592,16 @@ void ByteArrayColumnViewPrivate::placeCursor( const QPoint& point )
     adaptController();
 
     // get coord of click and whether this click was closer to the end of the pos
-    const Coord coord( mActiveColumn->magneticLinePositionOfX(point.x()), q->lineAt(point.y()) );
+    const int linePosition = mActiveColumn->magneticLinePositionOfX( point.x() );
+    const int lineIndex = q->lineAt( point.y() );
+    const Coord coord( linePosition, lineIndex );
 
     mTableCursor->gotoCCoord( coord );
     emit q->cursorPositionChanged( cursorPosition() );
 }
 
 
-int ByteArrayColumnViewPrivate::indexByPoint( const QPoint& point ) const
+Address ByteArrayColumnViewPrivate::indexByPoint( const QPoint& point ) const
 {
     Q_Q( const ByteArrayColumnView );
 
@@ -664,27 +678,25 @@ QRect ByteArrayColumnViewPrivate::cursorRect() const
 {
     Q_Q( const ByteArrayColumnView );
 
-    const int x = mActiveColumn->xOfLinePosition( mTableCursor->pos() ) - q->xOffset();
-    const int y = q->lineHeight() * mTableCursor->line() - q->yOffset();
-    const int w = mActiveColumn->byteWidth();
-    const int h = q->lineHeight();
-    const QPoint viewportPoint( x, y );
-    const QPoint point = q->viewport()->mapToParent( viewportPoint ); // TODO: seems still missing some offset
-    const QSize size( w, h );
+    QRect cursorRect = mActiveColumn->byteRect( mTableCursor->coord() );
+    const QPoint viewportPoint( cursorRect.x() - q->xOffset(), cursorRect.y() - q->yOffset() );
+    const QPoint globalPoint = q->viewport()->mapToParent( viewportPoint ); // TODO: seems still missing some offset
+    cursorRect.setTopLeft( globalPoint );
 
-    const QRect result( point, size );
-    return result;
+    return cursorRect;
 }
 
 void ByteArrayColumnViewPrivate::updateCursor( const AbstractByteArrayColumnRenderer& column )
 {
     Q_Q( ByteArrayColumnView );
 
-    const int x = column.xOfLinePosition( mTableCursor->pos() ) - q->xOffset();
-    const int y = q->lineHeight() * mTableCursor->line() - q->yOffset();
-    const int w = column.byteWidth();
+    if( ! column.isVisible() )
+        return;
 
-    q->viewport()->update( x,y, w,q->lineHeight() );
+    QRect cursorRect = column.byteRect( mTableCursor->coord() );
+    cursorRect.translate( -q->xOffset(), -q->yOffset() );
+
+    q->viewport()->update( cursorRect );
 }
 
 void ByteArrayColumnViewPrivate::createCursorPixmaps()
@@ -694,7 +706,7 @@ void ByteArrayColumnViewPrivate::createCursorPixmaps()
     // create mCursorPixmaps
     mCursorPixmaps->setSize( mActiveColumn->byteWidth(), q->lineHeight() );
 
-    const int index = mTableCursor->validIndex();
+    const Address index = mTableCursor->validIndex();
 
     QPainter painter;
     painter.begin( &mCursorPixmaps->offPixmap() );
@@ -708,8 +720,8 @@ void ByteArrayColumnViewPrivate::createCursorPixmaps()
     painter.end();
 
     // calculat the shape
-    KPixelX cursorX;
-    KPixelX cursorW;
+    PixelX cursorX;
+    PixelX cursorW;
     if( isCursorBehind() )
     {
         cursorX = qMax( 0, mCursorPixmaps->onPixmap().width()-InsertCursorWidth );
@@ -743,7 +755,7 @@ void ByteArrayColumnViewPrivate::drawActiveCursor( QPainter *painter )
     // paint edited byte?
     if( mValueEditor->isInEditMode() )
     {
-        const int index = mTableCursor->index();
+        const Address index = mTableCursor->index();
 
         if( mBlinkCursorVisible )
             mValueColumn->renderEditedByte( painter, mValueEditor->value(), mValueEditor->valueAsString() );
@@ -769,7 +781,7 @@ void ByteArrayColumnViewPrivate::drawInactiveCursor( QPainter *painter )
         || (!mCursorPaused && !q->hasFocus() && !q->viewport()->hasFocus() && !mDropper->isActive())  )
         return;
 
-    const int index = mTableCursor->validIndex();
+    const Address index = mTableCursor->validIndex();
 
     const int x = mInactiveColumn->xOfLinePosition( mTableCursor->pos() );
     const int y = q->lineHeight() * mTableCursor->line();
@@ -795,7 +807,7 @@ void ByteArrayColumnViewPrivate::renderColumns( QPainter* painter, int cx, int c
     // Then it needs to know about inactive, insideByte and the like... well...
     // perhaps subclassing the buffer columns even more, to CharByteArrayColumnRenderer and ValueByteArrayColumnRenderer?
 
-    if( q->visibleLines(KPixelYs::fromWidth(cy,ch)).includes(mTableCursor->line()) )
+    if( q->visibleLines(PixelYRange::fromWidth(cy,ch)).includes(mTableCursor->line()) )
     {
         drawActiveCursor( painter );
         drawInactiveCursor( painter );
@@ -807,10 +819,10 @@ void ByteArrayColumnViewPrivate::updateChanged()
     Q_Q( ByteArrayColumnView );
 
     const int xOffset = q->xOffset();
-    const KPixelXs Xs = KPixelXs::fromWidth( xOffset, q->visibleWidth() );
+    const PixelXRange Xs = PixelXRange::fromWidth( xOffset, q->visibleWidth() );
 
     // do updates in offset column 
-    const KHE::Section changedOffsetLines = mTableRanges->changedOffsetLines();
+    const LineRange changedOffsetLines = mTableRanges->changedOffsetLines();
     if( !changedOffsetLines.isEmpty() )
         q->updateColumn( *mOffsetColumn, changedOffsetLines );
 
@@ -835,24 +847,24 @@ void ByteArrayColumnViewPrivate::updateChanged()
     if( dirtyColumns.size() > 0 )
     {
         // calculate affected lines/indizes
-        const KHE::Section fullPositions( 0, mTableLayout->noOfBytesPerLine()-1 );
+        const LinePositionRange fullPositions( 0, mTableLayout->noOfBytesPerLine()-1 );
         CoordRange visibleRange( fullPositions, q->visibleLines() );
 
         const int lineHeight = q->lineHeight();
         CoordRange changedRange;
         // as there might be multiple selections on this line redo until no more is changed
-        while( hasChanged(visibleRange,&changedRange) )
+        while( getNextChangedRange(&changedRange,visibleRange) )
         {
-            KPixelY cy = q->yOffsetOfLine( changedRange.start().line() );
+            PixelY cy = q->yOffsetOfLine( changedRange.start().line() );
 
             QListIterator<AbstractByteArrayColumnRenderer*> columnIt( dirtyColumns );
             // only one line?
             if( changedRange.start().line() == changedRange.end().line() )
             {
-                const KHE::Section changedPositions( changedRange.start().pos(), changedRange.end().pos() );
+                const LinePositionRange changedPositions( changedRange.start().pos(), changedRange.end().pos() );
                 while( columnIt.hasNext() )
                 {
-                    const KPixelXs xPixels = columnIt.next()->xsOfLinePositionsInclSpaces( changedPositions );
+                    const PixelXRange xPixels = columnIt.next()->xsOfLinePositionsInclSpaces( changedPositions );
 
                     q->viewport()->update( xPixels.start()-xOffset, cy, xPixels.width(), lineHeight );
                 }
@@ -861,10 +873,10 @@ void ByteArrayColumnViewPrivate::updateChanged()
             else
             {
                 // first line
-                const KHE::Section firstChangedPositions( changedRange.start().pos(), fullPositions.end() );
+                const LinePositionRange firstChangedPositions( changedRange.start().pos(), fullPositions.end() );
                 while( columnIt.hasNext() )
                 {
-                    const KPixelXs XPixels = columnIt.next()->xsOfLinePositionsInclSpaces( firstChangedPositions );
+                    const PixelXRange XPixels = columnIt.next()->xsOfLinePositionsInclSpaces( firstChangedPositions );
 
                     q->viewport()->update( XPixels.start()-xOffset, cy, XPixels.width(), lineHeight );
                 }
@@ -876,7 +888,7 @@ void ByteArrayColumnViewPrivate::updateChanged()
                     columnIt.toFront();
                     while( columnIt.hasNext() )
                     {
-                        const KPixelXs XPixels = columnIt.next()->xsOfLinePositionsInclSpaces( fullPositions );
+                        const PixelXRange XPixels = columnIt.next()->xsOfLinePositionsInclSpaces( fullPositions );
 
                         q->viewport()->update( XPixels.start()-xOffset, cy, XPixels.width(), lineHeight );
                     }
@@ -884,10 +896,10 @@ void ByteArrayColumnViewPrivate::updateChanged()
                 // last line
                 cy += lineHeight;
                 columnIt.toFront();
-                const KHE::Section lastChangedPositions( fullPositions.start(), changedRange.end().pos() );
+                const LinePositionRange lastChangedPositions( fullPositions.start(), changedRange.end().pos() );
                 while( columnIt.hasNext() )
                 {
-                    const KPixelXs XPixels = columnIt.next()->xsOfLinePositionsInclSpaces( lastChangedPositions );
+                    const PixelXRange XPixels = columnIt.next()->xsOfLinePositionsInclSpaces( lastChangedPositions );
 
                     q->viewport()->update( XPixels.start()-xOffset, cy, XPixels.width(), lineHeight );
                 }
@@ -904,34 +916,34 @@ void ByteArrayColumnViewPrivate::updateChanged()
 }
 
 
-
 void ByteArrayColumnViewPrivate::ensureCursorVisible()
 {
-//   // Not visible or the user is dragging the window, so don't position to caret yet
-//   if ( !isVisible() || isHorizontalSliderPressed() || isVerticalSliderPressed() )
-//   {
-//     d->ensureCursorVisibleInShowEvent = true;
-//     return;
-//   }
-  //static const int Margin = 10;
     ensureVisible( *mActiveColumn, mTableCursor->coord() );
 }
 
+void ByteArrayColumnViewPrivate::ensureVisible( const AddressRange& range, bool ensureStartVisible )
+{
+    const CoordRange coords = mTableLayout->coordRangeOfIndizes( range );
+
+    // TODO: this is a make-it-work-hack, better do a smart calculation
+    ensureVisible( *mActiveColumn, ensureStartVisible ? coords.end() : coords.start() );
+    ensureVisible( *mActiveColumn, ensureStartVisible ? coords.start() : coords.end() );
+}
+
 void ByteArrayColumnViewPrivate::ensureVisible( const AbstractByteArrayColumnRenderer& column, const Coord& coord )
 {
     Q_Q( ByteArrayColumnView );
 
-    // TODO: add getCursorRect to BufferColumn
-    const KPixelXs cursorXs = KPixelXs::fromWidth( column.xOfLinePosition(coord.pos()),
-                                                   column.byteWidth() );
+    const QRect byteRect = column.byteRect( coord );
 
-    const KPixelYs cursorYs = KPixelYs::fromWidth( q->lineHeight()*coord.line(), q->lineHeight() );
+    const PixelXRange byteXs = PixelXRange::fromWidth( byteRect.x(), byteRect.width() );
+    const PixelYRange byteYs = PixelYRange::fromWidth( byteRect.y(), byteRect.height() );
 
-    const KPixelXs visibleXs = KPixelXs::fromWidth( q->xOffset(), q->visibleWidth() );
-    const KPixelYs visibleYs = KPixelXs::fromWidth( q->yOffset(), q->visibleHeight() );
+    const PixelXRange visibleXs = PixelXRange::fromWidth( q->xOffset(), q->visibleWidth() );
+    const PixelYRange visibleYs = PixelXRange::fromWidth( q->yOffset(), q->visibleHeight() );
 
-    q->horizontalScrollBar()->setValue( visibleXs.startForInclude(cursorXs) );
-    q->verticalScrollBar()->setValue( visibleYs.startForInclude(cursorYs) );
+    q->horizontalScrollBar()->setValue( visibleXs.startForInclude(byteXs) );
+    q->verticalScrollBar()->setValue( visibleYs.startForInclude(byteYs) );
 }
 
 
@@ -950,6 +962,8 @@ void ByteArrayColumnViewPrivate::mousePressEvent( QMouseEvent* mouseEvent )
 {
     Q_Q( ByteArrayColumnView );
 
+    const bool oldHasSelection = mTableRanges->hasSelection();
+
     pauseCursor();
     mValueEditor->finishEdit();
 
@@ -963,7 +977,7 @@ void ByteArrayColumnViewPrivate::mousePressEvent( QMouseEvent* mouseEvent )
             && (mouseEvent->globalPos()-mDoubleClickPoint).manhattanLength() < QApplication::startDragDistance() )
         {
             mTrippleClickTimer->stop();
-            const int indexAtFirstDoubleClickLinePosition = mTableLayout->indexAtFirstLinePosition( mDoubleClickLine );
+            const Address indexAtFirstDoubleClickLinePosition = mTableLayout->indexAtFirstLinePosition( mDoubleClickLine );
             mTableRanges->setSelectionStart( indexAtFirstDoubleClickLinePosition );
             mTableCursor->gotoIndex( indexAtFirstDoubleClickLinePosition );
             mTableCursor->gotoLineEnd();
@@ -971,7 +985,16 @@ void ByteArrayColumnViewPrivate::mousePressEvent( QMouseEvent* mouseEvent )
             updateChanged();
 
             unpauseCursor();
+
+            const bool newHasSelection = mTableRanges->hasSelection();
             emit q->cursorPositionChanged( cursorPosition() );
+            emit q->selectionChanged( mTableRanges->selection() );
+            if( oldHasSelection != newHasSelection )
+            {
+                if( !mOverWrite ) emit q->cutAvailable( newHasSelection );
+                emit q->copyAvailable( newHasSelection );
+                emit q->hasSelectedDataChanged( newHasSelection );
+            }
             return;
         }
 
@@ -989,7 +1012,7 @@ void ByteArrayColumnViewPrivate::mousePressEvent( QMouseEvent* mouseEvent )
             placeCursor( mousePoint );
             ensureCursorVisible();
 
-            const int realIndex = mTableCursor->realIndex();
+            const Address realIndex = mTableCursor->realIndex();
             if( mTableRanges->selectionStarted() )
             {
                 if( mouseEvent->modifiers() & Qt::SHIFT )
@@ -1021,6 +1044,15 @@ void ByteArrayColumnViewPrivate::mousePressEvent( QMouseEvent* mouseEvent )
     }
 
     unpauseCursor();
+
+    const bool newHasSelection = mTableRanges->hasSelection();
+    emit q->selectionChanged( mTableRanges->selection() );
+    if( oldHasSelection != newHasSelection )
+    {
+        if( !mOverWrite ) emit q->cutAvailable( newHasSelection );
+        emit q->copyAvailable( newHasSelection );
+        emit q->hasSelectedDataChanged( newHasSelection );
+    }
 }
 
 
@@ -1059,6 +1091,7 @@ void ByteArrayColumnViewPrivate::mouseReleaseEvent( QMouseEvent* mouseEvent )
 {
     Q_Q( ByteArrayColumnView );
 
+    const bool oldHasSelection = mTableRanges->hasSelection();
     const QPoint releasePoint = q->viewportToColumns( mouseEvent->pos() );
 
     // this is not the release of a doubleclick so we need to process it?
@@ -1066,7 +1099,7 @@ void ByteArrayColumnViewPrivate::mouseReleaseEvent( QMouseEvent* mouseEvent )
     {
         const int line = q->lineAt( releasePoint.y() );
         const int pos = mActiveColumn->linePositionOfX( releasePoint.x() ); // TODO: can we be sure here about the active column?
-        const int index = mTableLayout->indexAtCCoord( Coord(pos,line) ); // TODO: can this be another index than the one of the cursor???
+        const Address index = mTableLayout->indexAtCCoord( Coord(pos,line) ); // TODO: can this be another index than the one of the cursor???
         emit q->clicked( index );
     }
 
@@ -1136,10 +1169,14 @@ void ByteArrayColumnViewPrivate::mouseReleaseEvent( QMouseEvent* mouseEvent )
     if( mTableRanges->selectionJustStarted() )
         mTableRanges->removeSelection();
 
-    if( !mOverWrite ) emit q->cutAvailable( mTableRanges->hasSelection() );
-    emit q->copyAvailable( mTableRanges->hasSelection() );
-    emit q->selectionChanged( mTableRanges->hasSelection() );
+    const bool newHasSelection = mTableRanges->hasSelection();
     emit q->selectionChanged( mTableRanges->selection() );
+    if( oldHasSelection != newHasSelection )
+    {
+        if( !mOverWrite ) emit q->cutAvailable( newHasSelection );
+        emit q->copyAvailable( newHasSelection );
+        emit q->hasSelectedDataChanged( newHasSelection );
+    }
 }
 
 
@@ -1157,7 +1194,7 @@ void ByteArrayColumnViewPrivate::mouseDoubleClickEvent( QMouseEvent* mouseEvent
 
     mDoubleClickLine = mTableCursor->line();
 
-    const int index = mTableCursor->validIndex();
+    const Address index = mTableCursor->validIndex();
 
     if( mActiveColumn == mCharColumn )
     {
@@ -1190,6 +1227,7 @@ void ByteArrayColumnViewPrivate::handleMouseMove( const QPoint& point ) // handl
 {
     Q_Q( ByteArrayColumnView );
 
+    const bool oldHasSelection = mTableRanges->hasSelection();
     const int yOffset = q->yOffset();
     const int behindLastYOffset = yOffset + q->visibleHeight();
     // scrolltimer but inside of viewport?
@@ -1212,9 +1250,9 @@ void ByteArrayColumnViewPrivate::handleMouseMove( const QPoint& point ) // handl
     // do wordwise selection?
     if( mInDoubleClick && mTableRanges->hasFirstWordSelection() )
     {
-        int newIndex = mTableCursor->realIndex();
-        const KHE::Section firstWordSelection = mTableRanges->firstWordSelection();
-        const KHECore::WordByteArrayService WBS( mByteArrayModel, charCodec() );
+        Address newIndex = mTableCursor->realIndex();
+        const AddressRange firstWordSelection = mTableRanges->firstWordSelection();
+        const WordByteArrayService WBS( mByteArrayModel, charCodec() );
         // are we before the selection?
         if( firstWordSelection.startsBehind(newIndex) )
         {
@@ -1243,9 +1281,16 @@ void ByteArrayColumnViewPrivate::handleMouseMove( const QPoint& point ) // handl
     updateChanged();
 
     unpauseCursor();
+
+    const bool newHasSelection = mTableRanges->hasSelection();
     emit q->cursorPositionChanged( cursorPosition() );
-    emit q->selectionChanged( mTableRanges->hasSelection() );
     emit q->selectionChanged( mTableRanges->selection() );
+    if( oldHasSelection != newHasSelection )
+    {
+        if( !mOverWrite ) emit q->cutAvailable( newHasSelection );
+        emit q->copyAvailable( newHasSelection );
+        emit q->hasSelectedDataChanged( newHasSelection );
+    }
 }
 
 
@@ -1270,14 +1315,19 @@ void ByteArrayColumnViewPrivate::startDrag()
     Qt::DropAction dropAction = drag->exec( request );
 
     if( dropAction == Qt::MoveAction )
+    {
+        AbstractByteArrayView* targetByteArrayView = qobject_cast<AbstractByteArrayView*>( drag->target() );
         // Not inside this widget itself?
-        if( drag->target() != q )
+        if( ! targetByteArrayView
+            || targetByteArrayView->byteArrayModel() != q->byteArrayModel() )
             removeSelectedData();
+    }
 }
 
 ByteArrayColumnViewPrivate::~ByteArrayColumnViewPrivate()
 {
     delete mCursorPixmaps;
+    delete mStylist;
 }
 
 }
