@@ -22,53 +22,53 @@
 
 #include "offsetcolumnrenderer.h"
 
+// lib
+#include <abstractcolumnstylist.h>
 // lib
 #include "bytearraytablelayout.h"
-#include <columnsview.h>
 // Qt
 #include <QtGui/QPainter>
+#include <QtGui/QPalette>
 
 
-namespace KHEUI
+namespace Okteta
 {
 
-static const int leftOffsetMargin = 2;
-static const int rightOffsetMargin = 2;
+static const PixelX leftOffsetMargin = 2;
+static const PixelX rightOffsetMargin = 2;
 
 
-OffsetColumnRenderer::OffsetColumnRenderer( ColumnsView* columnsView,
-    ByteArrayTableLayout* layout, KOffsetFormat::KFormat format )
- : ColumnRenderer( columnsView ),
+OffsetColumnRenderer::OffsetColumnRenderer( AbstractColumnStylist* stylist,
+    ByteArrayTableLayout* layout, OffsetFormat::Format format )
+ : AbstractColumnRenderer( stylist ),
    mLayout( layout ),
    mDigitWidth( 0 ),
    mDigitBaseLine( 0 ),
-   mFormat( KOffsetFormat::None )
+   mFormat( OffsetFormat::None )
 {
     setFormat( format );
 }
 
-void OffsetColumnRenderer::renderLine( QPainter* painter, int lineIndex )
+void OffsetColumnRenderer::renderLine( QPainter* painter, Line lineIndex )
 {
-    const QWidget *viewport = columnsView()->viewport();
-
-    const int offset = mLayout->firstLineOffset() + mLayout->noOfBytesPerLine() * lineIndex;
+    const PixelX offset = mLayout->firstLineOffset() + mLayout->noOfBytesPerLine() * lineIndex;
     printFunction()( mCodedOffset, offset );
 
-    const QColor &buttonColor = viewport->palette().buttonText().color();
+    const QColor& buttonColor = stylist()->palette().buttonText().color();
     painter->setPen( buttonColor );
     painter->drawText( leftOffsetMargin, mDigitBaseLine, QString().append(mCodedOffset) );
 }
 
-void OffsetColumnRenderer::renderColumnBackground( QPainter* painter, const KPixelXs& _Xs, const KPixelYs& Ys )
+void OffsetColumnRenderer::renderColumnBackground( QPainter* painter, const PixelXRange& _Xs, const PixelYRange& Ys )
 {
-    KPixelXs Xs( _Xs );
+    PixelXRange Xs( _Xs );
     restrictToXSpan( &Xs );
 
-    const QBrush& buttonBrush = columnsView()->viewport()->palette().button();
+    const QBrush& buttonBrush = stylist()->palette().button();
     painter->fillRect( Xs.start(), Ys.start(), Xs.width(), Ys.width(), buttonBrush );
 }
 
-void OffsetColumnRenderer::renderFirstLine( QPainter *painter, const KPixelXs &, int firstLineIndex )
+void OffsetColumnRenderer::renderFirstLine( QPainter *painter, const PixelXRange &, Line firstLineIndex )
 {
     mRenderLineIndex = firstLineIndex;
     renderLine( painter, mRenderLineIndex++ );
@@ -81,18 +81,18 @@ void OffsetColumnRenderer::renderNextLine( QPainter *painter )
 }
 
 
-void OffsetColumnRenderer::renderColumn( QPainter* painter, const KPixelXs& Xs, const KPixelYs& Ys )
+void OffsetColumnRenderer::renderColumn( QPainter* painter, const PixelXRange& Xs, const PixelYRange& Ys )
 {
     renderColumnBackground( painter, Xs, Ys );
 }
 
 
-void OffsetColumnRenderer::renderEmptyColumn( QPainter* painter, const KPixelXs& Xs, const KPixelYs& Ys )
+void OffsetColumnRenderer::renderEmptyColumn( QPainter* painter, const PixelXRange& Xs, const PixelYRange& Ys )
 {
     renderColumnBackground( painter, Xs, Ys );
 }
 
-void OffsetColumnRenderer::setFormat( KOffsetFormat::KFormat format )
+void OffsetColumnRenderer::setFormat( OffsetFormat::Format format )
 {
     // no changes?
     if( mFormat == format )
@@ -100,19 +100,19 @@ void OffsetColumnRenderer::setFormat( KOffsetFormat::KFormat format )
 
     mFormat = format;
 
-    mCodingWidth = KOffsetFormat::codingWidth( mFormat );
-    PrintFunction = KOffsetFormat::printFunction( mFormat );
+    mCodingWidth = OffsetFormat::codingWidth( mFormat );
+    PrintFunction = OffsetFormat::printFunction( mFormat );
 
     recalcX();
 }
 
-void OffsetColumnRenderer::setMetrics( KPixelX digitWidth, KPixelY digitBaseLine )
+void OffsetColumnRenderer::setMetrics( PixelX digitWidth, PixelY digitBaseLine )
 {
     mDigitBaseLine = digitBaseLine;
     setDigitWidth( digitWidth );
 }
 
-void OffsetColumnRenderer::setDigitWidth( KPixelX digitWidth )
+void OffsetColumnRenderer::setDigitWidth( PixelX digitWidth )
 {
     // no changes?
     if( mDigitWidth == digitWidth )
