@@ -20,15 +20,16 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef KHE_UI_OFFSETCOLUMNRENDERER_H
-#define KHE_UI_OFFSETCOLUMNRENDERER_H
+#ifndef OKTETA_OFFSETCOLUMNRENDERER_H
+#define OKTETA_OFFSETCOLUMNRENDERER_H
 
 // lib
-#include "koffsetformat.h"
-#include "columnrenderer.h"
+#include "offsetformat.h"
+#include "abstractcolumnrenderer.h"
+#include "line.h"
 
 
-namespace KHEUI
+namespace Okteta
 {
 class ByteArrayTableLayout;
 
@@ -36,65 +37,65 @@ class ByteArrayTableLayout;
   *@author Friedrich W. H. Kossebau
   */
 
-class OffsetColumnRenderer : public ColumnRenderer
+class OKTETAGUI_EXPORT OffsetColumnRenderer : public AbstractColumnRenderer
 {
   public:
-    OffsetColumnRenderer( ColumnsView* columnsView, ByteArrayTableLayout* layout, KOffsetFormat::KFormat format );
+    OffsetColumnRenderer( AbstractColumnStylist* stylist, ByteArrayTableLayout* layout, OffsetFormat::Format format );
     virtual ~OffsetColumnRenderer();
 
-  public:  // ColumnRenderer API
-    virtual void renderFirstLine( QPainter *painter, const KPixelXs &Xs, int firstLineIndex );
-    virtual void renderNextLine( QPainter *painter );
-    virtual void renderColumn( QPainter* painter, const KPixelXs& Xs, const KPixelYs& Ys );
-    virtual void renderEmptyColumn( QPainter *painter, const KPixelXs &Xs, const KPixelYs &Ys );
+  public:  // AbstractColumnRenderer API
+    virtual void renderFirstLine( QPainter* painter, const PixelXRange& Xs, Line firstLineIndex );
+    virtual void renderNextLine( QPainter* painter );
+    virtual void renderColumn( QPainter* painter, const PixelXRange& Xs, const PixelYRange& Ys );
+    virtual void renderEmptyColumn( QPainter *painter, const PixelXRange &Xs, const PixelYRange &Ys );
 
   public:
-    void setFormat( KOffsetFormat::KFormat format );
+    void setFormat( OffsetFormat::Format format );
     /** sets width of digits and recalculates depend sizes  */
-    void setDigitWidth( KPixelX digitWidth );
+    void setDigitWidth( PixelX digitWidth );
     /** */
-    void setMetrics( KPixelX DW, KPixelY DBL );
+    void setMetrics( PixelX DW, PixelY DBL );
 
   public: // read access
 //     int delta() const;
     int codingWidth() const;
-    KOffsetFormat::print printFunction() const;
+    OffsetFormat::print printFunction() const;
 
 
   protected:
     /** recalculates all x values */
     void recalcX();
     /** paints full line */
-    void renderLine( QPainter *painter, int lineIndex );
+    void renderLine( QPainter *painter, Line lineIndex );
     /** */
-    void renderColumnBackground( QPainter* painter, const KPixelXs& Xs, const KPixelYs& Ys );
+    void renderColumnBackground( QPainter* painter, const PixelXRange& Xs, const PixelYRange& Ys );
 
   protected: // user settings
     ByteArrayTableLayout* mLayout;
 
   protected: // pixel related
     /** */
-    KPixelX mDigitWidth;
+    PixelX mDigitWidth;
     /** */
-    KPixelY mDigitBaseLine;
+    PixelY mDigitBaseLine;
 
   protected: // general layout
-    KOffsetFormat::KFormat mFormat;
+    OffsetFormat::Format mFormat;
 
     int mCodingWidth;
-    KOffsetFormat::print PrintFunction;
+    OffsetFormat::print PrintFunction;
 
     /** buffer to hold the formatted coding */
-    mutable char mCodedOffset[KOffsetFormat::MaxFormatWidth+1];
+    mutable char mCodedOffset[OffsetFormat::MaxFormatWidth+1];
 
   protected: // firstnext trips related
     /** */
-    int mRenderLineIndex;
+    Line mRenderLineIndex;
 };
 
 
 inline int OffsetColumnRenderer::codingWidth()                       const { return mCodingWidth; }
-inline KOffsetFormat::print OffsetColumnRenderer::printFunction()    const { return PrintFunction; }
+inline OffsetFormat::print OffsetColumnRenderer::printFunction()    const { return PrintFunction; }
 
 }
 
